import Vue from 'vue';
import Router from 'vue-router';
import { ZdPage } from '@zeedhi/vue';
import Store from './store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      name: 'home',
      component: ZdPage,
      props: () => ({
        path: 'home',
        local: true,
      }),
    },
    {
      path: '/login',
      name: 'login',
      component: ZdPage,
      props: () => ({
        path: 'login',
        local: true,
      }),
    },
		{
			path: '/gestao-de-demandas',
			component: ZdPage,
			name: 'demandManagement',
			props: {
				path: 'demandManagement/demandManagement',
				local: true,
			},
		},
    {
      path: '/modules/:module/:page',
      name: 'microservice',
      component: () => import('./views/Microservice.vue'),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
  ],
});

// router.beforeEach((to, from, next) => {
  // if (to.path !== '/login' && !localStorage.getItem('LOGIN_TOKEN')) {
    // next('/login');
  // } else {
    // next();
  // }
// });

router.beforeEach((to, from, next) => {
  if (window.parent !== window && to.name !== 'token-error') { // if application is called inside a iframe
      if (to.query.token) {
          // if token was passed
          localStorage.setItem('APP_LOGIN_TOKEN', JSON.stringify(to.query.token));
          if (to.query.hash !== '0') {
              localStorage.setItem('APP_LOGIN_HASH', JSON.stringify(to.query.hash));
              localStorage.setItem('APP_LOGIN_PRODUCT_ID', JSON.stringify(to.query.productId));
          }
          Store.commit('setAppLoginToken', to.query.token);
          Store.commit('setAppDisplayOptions', { menu: to.query.menu, header: to.query.header });
      }

      if (!Store.state.appLoginToken) {
          // if there is no token... redirect to another page
          Store.commit('setAppDisplayOptions', { menu: '0', header: '0' });
          next('/token-error');
          return;
      }

      // remove parameters from requested page
      delete to.query.menu;
      delete to.query.header;
      delete to.query.token;
  }

  next();
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, process.env.VUE_APP_MODULE_END_POINT);
    }
    window.document.title = `${process.env.VUE_APP_NAME} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = process.env.VUE_APP_NAME;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export default router;
